Learn R Programming

future (version 1.22.1)

MultiprocessFuture-class: A multiprocess future is a future whose value will be resolved asynchronously in a parallel process

Description

A multiprocess future is a future whose value will be resolved asynchronously in a parallel process

Usage

MultiprocessFuture(expr = NULL, substitute = TRUE, envir = parent.frame(), ...)

Arguments

expr
substitute

If TRUE, argument expr is substitute():ed, otherwise not.

envir

The environment from where global objects should be identified.

…

Additional named elements passed to Future().

Value

An object of class MultiprocessFuture.

See Also

To evaluate an expression using "multiprocess future", see function multiprocess().