View source: R/protected_api-result.R
| result.Future | R Documentation |
Get the results of a resolved future
## S3 method for class 'Future'
result(future, ...)
future |
A Future. |
... |
Not used. |
This function is only part of the backend Future API. This function is not part of the frontend Future API.
The FutureResult object. It may signal a FutureError, if there is a significant orchestration error. For example, if the parallel worker process terminated abruptly ("crashed"), then a FutureInterruptError is signaled.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.